@@ -1,3 +1,5 @@
+from typing import List
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
 from checkov.common.util.secrets import string_has_secrets, AWS
@@ -22,5 +24,8 @@ class EC2Credentials(BaseResourceCheck):
                         return CheckResult.FAILED
         return CheckResult.PASSED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ["Properties/UserData"]
+
 
 check = EC2Credentials()
