@@ -433,6 +433,16 @@ class Report:
                     record.check_result["suppress_comment"] = skip["suppress_comment"]
                     report.add_record(record)
 
+            if record.resource_address and record.resource_address.startswith("module."):
+                module_path = record.resource_address[0:record.resource_address.index('.', len("module.") + 1)]
+                module_enrichments = enriched_resources.get(module_path, {})
+                for module_skip in module_enrichments.get("skipped_checks", []):
+                    if record.check_id in module_skip["id"]:
+                        skip_records.append(record)
+                        record.check_result["result"] = CheckResult.SKIPPED
+                        record.check_result["suppress_comment"] = module_skip["suppress_comment"]
+                        report.add_record(record)
+
         for record in skip_records:
             if record in report.failed_checks:
                 report.failed_checks.remove(record)
