@@ -15,18 +15,6 @@ class DefaultServiceAccountBinding(BaseK8Check):
         categories = [CheckCategories.KUBERNETES]
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
-    # RoleBinding is namespaced... ClusterRoleBinding is not
-    def get_resource_id(self, conf):
-        if conf["kind"] == "ClusterRoleBinding":
-            return "ClusterRoleBinding.{}".format(conf["metadata"]["name"])
-        elif conf["kind"] == "RoleBinding":
-            if "namespace" in conf["metadata"]:
-                return "RoleBinding.{}.{}".format(conf["metadata"]["name"], conf["metadata"]["namespace"])
-            else:
-                return "RoleBinding.{}.default".format(conf["metadata"]["name"])
-        else:
-            return conf["kind"] + '.subjects'
-
     def scan_spec_conf(self, conf):
         if "subjects" in conf:
             for subject in conf["subjects"]:
