@@ -152,7 +152,7 @@ def run(banner=checkov_banner, argv=sys.argv[1:]):
                                                         repo_branch=config.branch)
             platform_excluded_paths = bc_integration.get_excluded_paths() or []
             runner_filter.excluded_paths = runner_filter.excluded_paths + platform_excluded_paths
-        except Exception as e:
+        except Exception:
             if bc_integration.prisma_url:
                 message = 'An error occurred setting up the Bridgecrew platform integration. Please check your API ' \
                           'token and PRISMA_API_URL environment variable and try again. The PRISMA_API_URL value ' \
