@@ -24,7 +24,8 @@ from checkov.serverless.parsers.parser import parse
 from checkov.common.parsers.node import DictNode
 from checkov.serverless.parsers.parser import CFN_RESOURCES_TOKEN
 
-SLS_FILE_MASK = ["serverless.yml", "serverless.yaml"]
+SLS_FILE_MASK = os.getenv(
+    "CKV_SLS_FILE_MASK", "serverless.yml,serverless.yaml").split(",")
 
 MULTI_ITEM_SECTIONS = [
     ("functions", function_registry),
@@ -97,7 +98,7 @@ class Runner(BaseRunner):
                 if not cf_sub_template.get('Resources'):
                     continue
                 cf_context_parser = CfnContextParser(sls_file, cf_sub_template, definitions_raw[sls_file])
-                logging.debug("Template Dump for {}: {}".format(sls_file, sls_file_data, indent=2))
+                logging.debug(f"Template Dump for {sls_file}: {sls_file_data}")
                 cf_context_parser.evaluate_default_refs()
                 for resource_name, resource in cf_sub_template['Resources'].items():
                     if not isinstance(resource, DictNode):
