@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_resource_negative_value_check import
 
 class RDSPubliclyAccessible(BaseResourceNegativeValueCheck):
     def __init__(self):
-        name = "Ensure all data stored in the RDS bucket is not public accessible"
+        name = "Ensure all data stored in RDS is not publicly accessible"
         id = "CKV_AWS_17"
         supported_resources = ['aws_db_instance', 'aws_rds_cluster_instance']
         categories = [CheckCategories.NETWORKING]
